@@ -1,5 +1,5 @@
 __all__ = ["dcmreaddata", "datareader", "datawriter", "rawN", "datasets"]
-__version__ = "2.5.1"
+__version__ = "2.5.7"
 # from pycut import Model, ImageGraphCut
 # from seed_editor_qt import QTSeedEditor
 from loguru import logger
@@ -12,4 +12,5 @@ from .datawriter import write
 from .datasets import download, read_dataset, joinp
 from .files import remove_if_exists
 from imma import image_manipulation, dili
-logger.disable('io3d')
+
+logger.disable("io3d")
