@@ -19,22 +19,29 @@ def deprecated(instructions):
     :param instructions: A human-friendly string of instructions, such as: 'Please migrate to add_proxy() ASAP.'
     :return: DeprecatedWarning
     """
+
     def decorator(func):
         """This is a decorator which can be used to mark functions as deprecated.
 
         It will result in a warning being emitted when the function is used.
         """
+
         @functools.wraps(func)
         def wrapper(*args, **kwargs):
-            message = 'Call to deprecated function {}. {}'.format(func.__name__,
-                                                                  instructions)
+            message = "Call to deprecated function {}. {}".format(
+                func.__name__, instructions
+            )
             frame = inspect.currentframe().f_back
-            warnings.warn_explicit(message,
-                                   category=DeprecatedWarning,
-                                   filename=inspect.getfile(frame.f_code),
-                                   lineno=frame.f_lineno)
+            warnings.warn_explicit(
+                message,
+                category=DeprecatedWarning,
+                filename=inspect.getfile(frame.f_code),
+                lineno=frame.f_lineno,
+            )
             return func(*args, **kwargs)
+
         return wrapper
+
     return decorator
 
 
@@ -42,5 +49,5 @@ def main():
     pass
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
