@@ -4,11 +4,11 @@
 # import sys
 import os
 
-import logging
-logger = logging.getLogger(__name__)
+from loguru import logger
 
 import numpy as np
 
+
 def ndarray_to_list_in_structure(item, squeeze=True):
     """ Change ndarray in structure of lists and dicts into lists.
     """
